# Baidu Docs Grabber

Convert and save documents from Baidu Docs (http://wenku.baidu.com)
to PDF for offline storage.

The required binary tools are already included for Windows. Linux users will need the
following listed binaries placed in the "bin/linux" folder. Instructions how to get 
them are included below.

* **dl-baidu-swf** - https://github.com/bazzinotti/dl-baidu-pdf

    grab source from Github address and build yourself

* **swfrender** - http://swftools.org

    included in most Linux distros as "swftools", grab the most recent build from website if not

* **img2pdf** - https://gitlab.mister-muffin.de/josch/img2pdf

    available from PyPi so can be installed from terminal with "pip install img2pdf"
